const { mergeWith } = require('lodash/fp')
const fs = require('fs-extra')

let custom = {}
const hasGatsbyConfig = fs.existsSync('./gatsby-config.custom.js')

if (hasGatsbyConfig) {
  try {
    custom = require('./gatsby-config.custom')
  } catch (err) {
    console.error(
      `Failed to load your gatsby-config.js file : `,
      JSON.stringify(err),
    )
  }
}

const config = {
  pathPrefix: '/',

  siteMetadata: {
    title: 'Ayanami document',
    description: 'document for ayanami',
  },
  plugins: [
    {
      resolve: 'gatsby-plugin-typescript',
      options: {
        isTSX: true,
        allExtensions: true,
      },
    },
    {
      resolve: 'gatsby-theme-docz',
      options: {
        themeConfig: {},
        themesDir: 'src',
        mdxExtensions: ['.md', '.mdx'],
        docgenConfig: {},
        menu: [
          'Introduction',
          {
            name: 'Basic',
            menu: [
              'Concept',
              { name: 'Action', route: '/en/basic/action' },
              { name: 'Effects', route: '/en/basic/effects' },
              {
                name: 'Dependencies Injection',
                route: '/en/basic/dependencies-injection',
              },
            ],
          },
          {
            name: 'Recipes',
            menu: [
              'Cancellation',
              'Loading/Error states handling',
              'StateSelector',
              'Dependencies Replacement',
              'Adding new module asynchronously',
              'Writting tests',
            ],
          },
          { name: 'FAQ', route: '/en/faq' },
          {
            name: '基本概念',
            menu: [
              '概念',
              { name: 'Action', route: '/zh/basic/action' },
              { name: 'Effects', route: '/zh/basic/effects' },
              { name: '依赖注入', route: '/zh/basic/dependencies-injection' },
            ],
          },
          {
            name: '深入',
            menu: [
              '取消',
              '处理 Loading/Error 状态',
              '依赖替换',
              'Module 异步加载',
              '测试',
            ],
          },
          { name: '常见问题', route: '/zh/faq' },
        ],
        mdPlugins: [],
        hastPlugins: [],
        ignore: [],
        typescript: true,
        ts: false,
        propsParser: true,
        'props-parser': true,
        debug: false,
        native: false,
        openBrowser: false,
        o: false,
        open: false,
        'open-browser': false,
        root: '/Users/longyinan/workspace/github/ayanami/docs/.docz',
        base: '/',
        source: './',
        src: './',
        files: './**/*.mdx',
        public: '/public',
        dest: 'public',
        d: '.docz/dist',
        editBranch: 'master',
        eb: 'master',
        'edit-branch': 'master',
        config: '',
        title: 'Ayanami document',
        description: 'document for ayanami',
        host: 'localhost',
        port: 3000,
        p: 3000,
        separator: '-',
        paths: {
          root: '/Users/longyinan/workspace/github/ayanami/docs',
          templates:
            '/Users/longyinan/workspace/github/ayanami/docs/node_modules/docz-core/dist/templates',
          docz: '/Users/longyinan/workspace/github/ayanami/docs/.docz',
          cache: '/Users/longyinan/workspace/github/ayanami/docs/.docz/.cache',
          app: '/Users/longyinan/workspace/github/ayanami/docs/.docz/app',
          appPackageJson:
            '/Users/longyinan/workspace/github/ayanami/docs/package.json',
          gatsbyConfig:
            '/Users/longyinan/workspace/github/ayanami/docs/gatsby-config.js',
          gatsbyBrowser:
            '/Users/longyinan/workspace/github/ayanami/docs/gatsby-browser.js',
          gatsbyNode:
            '/Users/longyinan/workspace/github/ayanami/docs/gatsby-node.js',
          gatsbySSR:
            '/Users/longyinan/workspace/github/ayanami/docs/gatsby-ssr.js',
          importsJs:
            '/Users/longyinan/workspace/github/ayanami/docs/.docz/app/imports.js',
          rootJs:
            '/Users/longyinan/workspace/github/ayanami/docs/.docz/app/root.jsx',
          indexJs:
            '/Users/longyinan/workspace/github/ayanami/docs/.docz/app/index.jsx',
          indexHtml:
            '/Users/longyinan/workspace/github/ayanami/docs/.docz/app/index.html',
          db:
            '/Users/longyinan/workspace/github/ayanami/docs/.docz/app/db.json',
        },
      },
    },
  ],
}

const merge = mergeWith((objValue, srcValue) => {
  if (Array.isArray(objValue)) {
    return objValue.concat(srcValue)
  }
})

module.exports = merge(config, custom)
